@@ -23,13 +23,13 @@
 
 #include "config.h" // GLOM_ENABLE_CLIENT_ONLY
 
-#include "box_data.h"
+#include "box_data_manyrecords.h"
 #include "../utility_widgets/db_adddel/db_adddel_withbuttons.h"
 
 namespace Glom
 {
 
-class Box_Data_List : public Box_Data
+class Box_Data_List : public Box_Data_ManyRecords
 {
 public: 
   Box_Data_List();
@@ -37,11 +37,10 @@ public:
 
   void refresh_data_from_database_blank();
 
-  virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row);
-  virtual Gnome::Gda::Value get_primary_key_value_selected();
-  Gnome::Gda::Value get_primary_key_value_first();
+  Gnome::Gda::Value get_primary_key_value_first() const;
 
-  ///This allows Box_Data::record_new() to set the generated/entered primary key value, needed by Box_Data_List:
+  //Implementations of pure virtual methods from Base_DB_Table_Data:
+  virtual Gnome::Gda::Value get_primary_key_value_selected() const;
   virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
 
   virtual Gnome::Gda::Value get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const;
@@ -58,9 +57,6 @@ public:
   ///Highlight and scroll to the specified record, with primary key value @primary_key_value.
   void set_primary_key_value_selected(const Gnome::Gda::Value& primary_key_value);
 
-  //Primary Key value:
-  typedef sigc::signal<void, const Gnome::Gda::Value&> type_signal_user_requested_details;
-  type_signal_user_requested_details signal_user_requested_details();
 
   //Signal Handlers:
   virtual void on_details_nav_first();
@@ -71,44 +67,52 @@ public:
 
   void get_record_counts(gulong& total, gulong& found) const;
 
+  #ifndef GLOM_ENABLE_CLIENT_ONLY
+  virtual void on_dialog_layout_hide(); //override
+  #endif //GLOM_ENABLE_CLIENT_ONLY
+
+
 protected:
+
+  //Implementations of pure virtual methods from Base_DB_Table_Data:
+  virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const;
+
+  //Overrides of functions from Box_Data:
   virtual void create_layout(); //override
-  virtual Document_Glom::type_mapLayoutGroupSequence create_layout_get_layout(); //overriden in Box_Data_List_Related.
+  virtual Document_Glom::type_list_layout_groups create_layout_get_layout();
   void create_layout_add_group(const sharedptr<LayoutGroup>& layout_group);
+    
   virtual bool fill_from_database(); //override.
   virtual void enable_buttons();
 
-  virtual bool get_field_primary_key_index(guint& field_column) const; //TODO: visible 
   virtual sharedptr<Field> get_field_primary_key() const;
 
   //Signal handlers:
-  virtual void on_adddel_user_requested_add();
-  virtual void on_adddel_user_requested_edit(const Gtk::TreeModel::iterator& row);
-  virtual void on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
-  virtual void on_adddel_user_added(const Gtk::TreeModel::iterator& row, guint col_with_first_value);
-  virtual void on_adddel_user_reordered_columns();
+  void on_adddel_user_requested_edit(const Gtk::TreeModel::iterator& row);
+  void on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
+  void on_adddel_user_reordered_columns();
+  void on_adddel_user_sort_clause_changed();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual void on_adddel_user_requested_layout();
+  void on_adddel_user_requested_layout();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
-  virtual void on_adddel_script_button_clicked(const sharedptr<const LayoutItem_Button>& layout_item, const Gtk::TreeModel::iterator& row);
+  void on_adddel_script_button_clicked(const sharedptr<const LayoutItem_Button>& layout_item, const Gtk::TreeModel::iterator& row);
   virtual bool on_script_button_idle(const Gnome::Gda::Value& primary_key_value);
 
-  virtual void on_record_added(const Gnome::Gda::Value& primary_key_value, const Gtk::TreeModel::iterator& row); //Not a signal handler. To be overridden.
-  virtual void on_record_deleted(const Gnome::Gda::Value& primary_key_value);
-
   virtual void print_layout();
   virtual void print_layout_group(xmlpp::Element* node_parent, const sharedptr<const LayoutGroup>& group);
 
-  //Member widgers:
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  virtual Dialog_Layout* create_layout_dialog() const; // override.
+  virtual void prepare_layout_dialog(Dialog_Layout* dialog); // override.
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  //Member widgets:
   mutable DbAddDel_WithButtons m_AddDel; //mutable because its get_ methods aren't const.
 
   bool m_has_one_or_more_records;
   bool m_read_only;
-
-  type_signal_user_requested_details m_signal_user_requested_details;
 };
 
 } //namespace Glom
