@@ -248,27 +248,32 @@ Box_Data_List_Related* FlowTableWithFields::create_related(const sharedptr<Layou
   Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
   if(pDocument)
   {
+    Box_Data_List_Related* portal_box = Gtk::manage(new Box_Data_List_Related);
+    add_view(portal_box); //Give it access to the document, needed to get the layout and fields information.
+
+    //Create the layout:
+    if(portal && portal->get_has_relationship_name())
+      portal_box->init_db_details(portal, show_title);
+    else
+      portal_box->init_db_details(m_table_name, show_title);
+
+    Glib::ustring to_table;
     sharedptr<Relationship> relationship = pDocument->get_relationship(m_table_name, portal->get_relationship_name());
     if(relationship)
-    {
-      Box_Data_List_Related* portal_box = Gtk::manage(new Box_Data_List_Related);
-      add_view(portal_box); //Give it access to the document, needed to get the layout and fields information.
+      to_table = relationship->get_to_table();
 
-      portal_box->init_db_details(portal, show_title); //Create the layout
+    portal_box->set_layout_item(portal, to_table);
+    portal_box->show();
 
-      portal_box->set_layout_item(portal, relationship->get_to_table());
-      portal_box->show();
+    m_portals.push_back(portal_box);
 
-      m_portals.push_back(portal_box);
+    //Connect signals:
+    //Just reemit this object's signal when receiving the same signal from the portal:
+    signal_connect_for_reemit_1arg(portal_box->signal_portal_record_changed(), signal_related_record_changed());
 
-      //Connect signals:
-      //Just reemit this object's signal when receiving the same signal from the portal:
-      signal_connect_for_reemit_1arg(portal_box->signal_portal_record_changed(), signal_related_record_changed());
+    portal_box->signal_user_requested_details().connect( sigc::bind( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_user_requested_details), portal_box));
 
-      portal_box->signal_user_requested_details().connect( sigc::bind( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_user_requested_details), portal_box));
-
-      return portal_box;
-    }
+    return portal_box;
   }
 
   return 0;
@@ -282,27 +287,32 @@ Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const sh
   Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
   if(pDocument)
   {
+    Box_Data_Calendar_Related* portal_box = Gtk::manage(new Box_Data_Calendar_Related);
+    add_view(portal_box); //Give it access to the document, needed to get the layout and fields information.
+
+    //Create the layout:
+    if(portal && portal->get_has_relationship_name())
+      portal_box->init_db_details(portal, show_title);
+    else
+      portal_box->init_db_details(m_table_name, show_title);
+
+    Glib::ustring to_table;
     sharedptr<Relationship> relationship = pDocument->get_relationship(m_table_name, portal->get_relationship_name());
     if(relationship)
-    {
-      Box_Data_Calendar_Related* portal_box = Gtk::manage(new Box_Data_Calendar_Related);
-      add_view(portal_box); //Give it access to the document, needed to get the layout and fields information.
+      to_table = relationship->get_to_table();
 
-      portal_box->init_db_details(portal, show_title); //Create the layout
+    portal_box->set_layout_item(portal, to_table);
+    portal_box->show();
 
-      portal_box->set_layout_item(portal, relationship->get_to_table());
-      portal_box->show();
+    m_portals.push_back(portal_box);
 
-      m_portals.push_back(portal_box);
+    //Connect signals:
+    //Just reemit this object's signal when receiving the same signal from the portal:
+    signal_connect_for_reemit_1arg(portal_box->signal_portal_record_changed(), signal_related_record_changed());    
 
-      //Connect signals:
-      //Just reemit this object's signal when receiving the same signal from the portal:
-      signal_connect_for_reemit_1arg(portal_box->signal_portal_record_changed(), signal_related_record_changed());    
+    portal_box->signal_user_requested_details().connect( sigc::bind( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_user_requested_details), portal_box));
 
-      portal_box->signal_user_requested_details().connect( sigc::bind( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_user_requested_details), portal_box));
-
-      return portal_box;
-    }
+    return portal_box;
   }
 
   return 0;
@@ -322,6 +332,8 @@ void FlowTableWithFields::add_layout_portal_at_position(const sharedptr<LayoutIt
     add(*portal_box, true /* expand */);
     add_layoutwidgetbase(portal_box, add_before);
   }
+  else
+    std::cerr << "FlowTableWithFields::add_layout_portal_at_position(): No portal was created." << std::endl;
 }
 
 void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<LayoutItem_Notebook>& notebook, const type_list_layoutwidgets::iterator& add_before)
@@ -1100,39 +1112,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
   }
   else if(item_type == LayoutWidgetBase::TYPE_PORTAL)
   {
-    try
-    {
-      Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
-
-      Dialog_ChooseRelationship* dialog = 0;
-      refXml->get_widget_derived("dialog_choose_relationship", dialog);
-
-      if(dialog)
-      {
-        Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
-        dialog->set_document(pDocument, m_table_name);
-        //TODO: dialog->set_transient_for(*get_app_window());
-        const int response = dialog->run();
-        dialog->hide();
-        if(response == Gtk::RESPONSE_OK)
-        {
-          //Get the chosen relationship:
-          sharedptr<Relationship> relationship  = dialog->get_relationship_chosen();
-          if(relationship)
-          {
-            sharedptr<LayoutItem_Portal> layout_item = sharedptr<LayoutItem_Portal>::create();
-            layout_item->set_relationship(relationship);
-            layout_item_new = layout_item;
-          }
-        }
-
-        delete dialog;
-      }
-    }
-    catch(const Gnome::Glade::XmlError& ex)
-    {
-      std::cerr << ex.what() << std::endl;
-    }
+    layout_item_new = get_portal_relationship();
   }
   else if(item_type == LayoutWidgetBase::TYPE_BUTTON)
   {
@@ -1238,6 +1218,20 @@ void FlowTableWithFields::on_dnd_add_layout_notebook (LayoutWidgetBase* above)
   signal_layout_changed().emit();
 }
 
+void FlowTableWithFields::on_dnd_add_layout_portal (LayoutWidgetBase* above)
+{
+  sharedptr<LayoutItem_Portal> portal = get_portal_relationship();
+  
+  if (portal)
+  {
+    sharedptr<LayoutItem> item = sharedptr<LayoutItem>::cast_dynamic(portal);
+    dnd_add_to_layout_group (item, above);
+    
+    //Tell the parent to tell the document to save the layout
+    signal_layout_changed().emit();
+  }
+}
+
 void FlowTableWithFields::on_dnd_add_layout_group(LayoutWidgetBase* above)
 {  
   sharedptr<LayoutGroup> group(new LayoutGroup());
@@ -1410,6 +1404,7 @@ sharedptr<LayoutItem_Portal> FlowTableWithFields::get_layout_item_from_relation(
   return layout_item;
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void FlowTableWithFields::on_menu_properties_activate()
 {
   try
@@ -1480,4 +1475,43 @@ bool FlowTableWithFields::on_button_press_event(GdkEventButton *event)
   return Gtk::Widget::on_button_press_event(event);
 }
 
+sharedptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship()
+{
+  try
+  {
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_relationship");
+    
+    Dialog_ChooseRelationship* dialog = 0;
+    refXml->get_widget_derived("dialog_choose_relationship", dialog);
+    
+    if(dialog)
+    {
+      Document_Glom* pDocument = static_cast<Document_Glom*>(get_document());
+      dialog->set_document(pDocument, m_table_name);
+      //TODO: dialog->set_transient_for(*get_app_window());
+      const int response = dialog->run();
+      dialog->hide();
+      if(response == Gtk::RESPONSE_OK)
+      {
+        //Get the chosen relationship:
+        sharedptr<Relationship> relationship  = dialog->get_relationship_chosen();
+        if(relationship)
+        {
+          sharedptr<LayoutItem_Portal> layout_item = sharedptr<LayoutItem_Portal>::create();
+          layout_item->set_relationship(relationship);
+          return layout_item;
+        }
+      }
+      
+      delete dialog;
+    }
+  }
+  catch(const Gnome::Glade::XmlError& ex)
+  {
+    std::cerr << ex.what() << std::endl;
+  }
+  return sharedptr<LayoutItem_Portal>();
+}
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
 } //namespace Glom
