@@ -22,6 +22,7 @@
 #include "dialog_user.h"
 #include "dialog_choose_user.h"
 #include <glom/glom_privs.h>
+#include <glom/libglom/glade_utils.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 //#include <libgnome/gnome-i18n.h>
 #include <glibmm/i18n.h>
@@ -46,10 +47,6 @@ Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<G
   refGlade->get_widget("treeview_users", m_treeview_users);
   if(m_treeview_users)
   {
-    m_treeview_users->set_reorderable();
-    m_treeview_users->enable_model_drag_source();
-    m_treeview_users->enable_model_drag_dest();
-
     Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_users->get_selection();
     if(refSelection)
     {
@@ -92,70 +89,6 @@ Dialog_UsersList::~Dialog_UsersList()
 {
 }
 
-/*
-void Dialog_UsersList::set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
-{
-  m_modified = false;
-
-  Dialog_Layout::set_document(layout, document, table_name, table_fields);
-
-
-  //Update the tree models from the document
-  if(document)
-  {
-    //Set the table name and title:
-    m_label_table_name->set_text(table_name);
-    m_entry_table_title->set_text( document->get_table_title(table_name) );
-
-    Document_Glom::type_mapLayoutGroupSequence mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name);
-
-    //If no information is stored in the document, then start with something:
-
-    if(mapGroups.empty())
-    {
-      LayoutGroup group;
-      group.set_name("main");
-      group.m_columns_count = 2;
-
-      guint field_sequence = 1; //0 means no sequence
-      for(type_vecLayoutFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
-      {
-        LayoutItem_Field item = *iter;
-        item.m_sequence = field_sequence;
-
-        group.add_item(item, field_sequence);
-
-        ++field_sequence;
-      }
-
-      mapGroups[1] = group;
-    }
-
-    //Show the field layout
-    typedef std::list< Glib::ustring > type_listStrings;
-
-    m_model_users->clear();
-
-    //guint field_sequence = 1; //0 means no sequence
-    //guint group_sequence = 1; //0 means no sequence
-    for(Document_Glom::type_mapLayoutGroupSequence::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
-    {
-      sharedptr<const LayoutGroup> group = iter->second;
-
-      add_group(Gtk::TreeModel::iterator(), group);
-    }
-
-    //treeview_fill_sequences(m_model_users, m_model_users->m_columns.m_col_sequence); //The document should have checked this already, but it does not hurt to check again.
-  }
-
-  //Open all the groups:
-  m_treeview_users->expand_all();
-
-  m_modified = false;
-
-}
-*/
-
 void Dialog_UsersList::enable_buttons()
 {
   if(!m_button_user_edit)
@@ -251,7 +184,7 @@ void Dialog_UsersList::on_button_user_add()
   Dialog_ChooseUser* dialog = 0;
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_choose_user");
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_user");
 
     refXml->get_widget_derived("dialog_choose_user", dialog);
   }
@@ -298,7 +231,7 @@ void Dialog_UsersList::on_button_user_new()
   Dialog_User* dialog = 0;
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_user");
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_user");
 
     refXml->get_widget_derived("dialog_user", dialog);
   }
@@ -364,7 +297,7 @@ void Dialog_UsersList::on_button_user_edit()
       Dialog_User* dialog = 0;
       try
       {
-        Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_user");
+        Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_user");
 
         refXml->get_widget_derived("dialog_user", dialog);
       }
